@@ -1,4 +1,5 @@
 
+import sys
 from setuptools import Extension
 from setuptools import setup
 
@@ -6,7 +7,7 @@ base = 'https://sourceforge.net/p/ruamel-yaml-clibz/'
 
 setup(
     name='ruamel.yaml.clibz',
-    version='0.3.1',
+    version='0.3.3',
     python_requires='>=3.9',
     build_zig=True,
     author='Anthon van der Neut',
@@ -39,5 +40,5 @@ setup(
             # '-O', 'Debug',
         ],
     )],
-    setup_requires=['setuptools-zig>=0.4.2', 'ziglang<0.16'],
+    setup_requires=[] if 'egg_info' in sys.argv else ['setuptools-zig>=0.5.1', 'ziglang<0.16'],
 )
